summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorNicolas Hennion <nicolashennion@gmail.com>2014-11-12 13:31:46 +0100
committerNicolas Hennion <nicolashennion@gmail.com>2014-11-12 13:31:46 +0100
commit54b1efab687a66d93d862ceb0b9b10609d5e3140 (patch)
tree6447570f156c16ad24d9134eee0960bb8be303c6
parentb93a51348c065c4660d16798208574997baf57b6 (diff)
parent6fdb2fc67cd056e8ce51e9a7f18c620d9fec06b7 (diff)
Merge pull request #443 from hdiogenes/master
Spelling correction for "openned".
-rw-r--r--NEWS2
-rw-r--r--docs/glances-doc.html2
-rw-r--r--docs/glances-doc.rst2
-rw-r--r--glances/plugins/glances_processlist.py4
4 files changed, 5 insertions, 5 deletions
diff --git a/NEWS b/NEWS
index f4055f2a..96eef545 100644
--- a/NEWS
+++ b/NEWS
@@ -35,7 +35,7 @@ Version 2.1
or by pressing the ENTER key in the curse interface.
For the moment, process filter feature is only available in standalone mode.
* Add extended processes informations for top process
- Top process stats availables: CPU affinity, extended memory information (shared, text, lib, datat, dirty, swap), openned threads/files and TCP/UDP network sessions, IO nice level
+ Top process stats availables: CPU affinity, extended memory information (shared, text, lib, datat, dirty, swap), open threads/files and TCP/UDP network sessions, IO nice level
For the moment, extended processes stats are only available in standalone mode.
* Add --process-short-name tag and '/' key to switch between short/command line
* Create a max_processes key in the configuration file
diff --git a/docs/glances-doc.html b/docs/glances-doc.html
index 32121e8c..af6ad486 100644
--- a/docs/glances-doc.html
+++ b/docs/glances-doc.html
@@ -699,7 +699,7 @@ User cans switch to the process name by pressing on the <tt class="docutils lite
<ul class="simple">
<li>CPU affinity (number of cores used by the process)</li>
<li>Extended memory information (swap, shared, text, lib, data and dirty on Linux)</li>
-<li>Openned threads, files and network sessions (TCP and UDP)</li>
+<li>Open threads, files and network sessions (TCP and UDP)</li>
<li>IO nice level</li>
</ul>
<p>The extended stats feature could be disabled using the --disable-process-extended option (command line) or the <tt class="docutils literal">e</tt> key (curses interface).</p>
diff --git a/docs/glances-doc.rst b/docs/glances-doc.rst
index db28942e..85c43a15 100644
--- a/docs/glances-doc.rst
+++ b/docs/glances-doc.rst
@@ -538,7 +538,7 @@ In standalone mode, additionals informations are provided for the top process:
* CPU affinity (number of cores used by the process)
* Extended memory information (swap, shared, text, lib, data and dirty on Linux)
-* Openned threads, files and network sessions (TCP and UDP)
+* Open threads, files and network sessions (TCP and UDP)
* IO nice level
The extended stats feature could be disabled using the --disable-process-extended option (command line) or the ``e`` key (curses interface).
diff --git a/glances/plugins/glances_processlist.py b/glances/plugins/glances_processlist.py
index 3262d72d..0c368e45 100644
--- a/glances/plugins/glances_processlist.py
+++ b/glances/plugins/glances_processlist.py
@@ -260,7 +260,7 @@ class Plugin(GlancesPlugin):
if 'memory_swap' in p and p['memory_swap'] is not None:
msg += _('swap ') + self.auto_unit(p['memory_swap'], low_precision=False)
ret.append(self.curse_add_line(msg, splittable=True))
# Third line is for openned files/network sessions
msg = ''
if 'num_threads' in p and p['num_threads'] is not None:
msg += _('threads ') + str(p['num_threads']) + ' '
@@ -274,7 +274,7 @@ class Plugin(GlancesPlugin):
msg += _('UDP ') + str(p['udp']) + ' '
if msg != '':
ret.append(self.curse_new_line())
- msg = xpad + _('Openned: ') + msg
+ msg = xpad + _('Open: ') + msg
ret.append(self.curse_add_line(msg, splittable=True))
# Fouth line is IO nice level (only Linux and Windows OS)
if 'ionice' in p and p['ionice'] is not None:
@@ -260,7 +260,7 @@ class Plugin(GlancesPlugin):
msg += _('swap ') + self.auto_unit(p['memory_swap'], low_precision=False)
ret.append(self.curse_add_line(msg, splittable=True))
- # Third line is for openned files/network sessions
+ # Third line is for open files/network sessions
msg = ''
if 'num_threads' in p and p['num_threads'] is not None: